@@ -4,7 +4,7 @@ Elements for the gui to display.
 import collections.abc
 import math
 import warnings
-from typing import Optional, Union
+from typing import List, Optional, Union
 
 import imgui
 
@@ -98,9 +98,10 @@ class Elements:
     def text(
         self,
         text: str,
-        text_color: Union[tuple, int] = (255, 255, 255, 1),
+        text_color: Optional[Union[tuple, int]] = None,
         center: bool = False,
         wrap_text: bool = True,
+        font_size: Union[int, float] = 48,
     ) -> None:
         """
         Add's a text element to the GUI.
@@ -115,6 +116,8 @@ class Elements:
             Wether or not the text should be centered, by default False
         wrap_text : bool, optional
             Wether or not the text should be wrapped, by default True
+        font_size : Union[int, float], optional
+            The font size of the text, by default 48
         """
         if center and wrap_text:
             warnings.warn(
@@ -140,7 +143,11 @@ class Elements:
             imgui.set_cursor_pos_x((window_width - text_width) / 2)
         if wrap_text:
             imgui.push_text_wrap_pos(imgui.get_window_width() * WRAPPING_PERCENTAGE)
+        if font_size != 48:
+            imgui.set_window_font_scale(font_size / 48)
         imgui.text(text)
+        if font_size != 48:
+            imgui.set_window_font_scale(1.0)
         if isinstance(text_color, tuple):
             imgui.pop_style_color()
         if wrap_text:
@@ -149,9 +156,9 @@ class Elements:
     def button(
         self,
         text: str,
-        text_color: Union[tuple, int] = (255, 255, 255, 1),
+        text_color: Optional[Union[tuple, int]] = None,
         wrap_text: bool = True,
-        key: Optional[str] = None
+        key: Optional[str] = None,
     ):
         """
         Create a button element.
@@ -216,6 +223,7 @@ class Elements:
         Callable
             A decorator for handling element's that only get rendered after a button click.
         """
+
         def handler(func):
             if imgui.get_time() - self.state.get(key, -math.inf) < time_limit:
                 func()
@@ -244,7 +252,7 @@ class Elements:
         """
         changed, value = imgui.checkbox(
             " " + label,
-            self.state.get(
+            self.state.setdefault(
                 key or label, default_value
             ),  # Adding a space to the label make's it look better
         )
@@ -296,7 +304,7 @@ class Elements:
                     default_value = default_value + (old_default_value[3],)
         changed, value = func(
             " " + label,  # Adding a space to the label make's it look better
-            *self.state.get(key or label, default_value),
+            *self.state.setdefault(key or label, default_value),
         )
         if changed:
             self.state[key or label] = value
@@ -341,7 +349,7 @@ class Elements:
         if wrap_text:
             imgui.push_text_wrap_pos(imgui.get_window_width() * WRAPPING_PERCENTAGE)
         changed, value = imgui.input_int(
-            " " + label, self.state.get(key or label, default_value)
+            " " + label, self.state.setdefault(key or label, default_value)
         )  # Adding a space to the label make's it look better
         if wrap_text:
             imgui.pop_text_wrap_pos()
@@ -382,10 +390,52 @@ class Elements:
         if wrap_text:
             imgui.push_text_wrap_pos(imgui.get_window_width() * WRAPPING_PERCENTAGE)
         changed, value = imgui.input_text(
-            " " + label, self.state.get(key or label, default_value), max_length + 1
+            " " + label,
+            self.state.setdefault(key or label, default_value),
+            max_length + 1,
         )  # Adding a space to the label make's it look better
         if wrap_text:
             imgui.pop_text_wrap_pos()
         if changed:
             self.state[key or label] = value
         return value
+
+    def combo(
+        self,
+        label: str,
+        default_value: int,
+        choices: List[str],
+        key: Optional[str] = None,
+        wrap_text: bool = True,
+    ) -> int:
+        """
+        Create a combo element and add it to the frame.
+
+        Parameters
+        ----------
+        label : str
+            The text to be displayed after the combo.
+        default_value : int
+            The default value of the combo. This should be the index of the choice in the choices list.
+        choices : List[str]
+            The list of choices to be displayed in the combo.
+        key : Optional[str], optional
+            A key for the combo. This can be used for accessing the state of the element before it is added to the frame, by default None
+        wrap_text : bool, optional
+            Wether or not the text should be wrapped to fit, by default True
+
+        Returns
+        -------
+        int
+            The index of the selected value.
+        """
+        if wrap_text:
+            imgui.push_text_wrap_pos(imgui.get_window_width() * WRAPPING_PERCENTAGE)
+        changed, value = imgui.combo(
+            " " + label, self.state.setdefault(key or label, default_value), choices
+        )  # Adding a space to the label make's it look better
+        if changed:
+            self.state[key or label] = value
+        if wrap_text:
+            imgui.pop_text_wrap_pos()
+        return value
